Quizz Starr!!!

This is a simple CLI app.
It generates randoms questions from Open Trivia API and stores the generated questions in json in question.json (multiple choice and boolean questions)

Each user is able to signup/login and choose the number of questions he/she wants to answer.

REQUIREMENTs
 * Python 3.8
 * PyPI

INSTALL
 * Download python 3.8 (add python to path during installation)
 * pip install quizstarr

PLAY/RUN
 * open cmd as an administrator
 * input python -m quizstarr
